@@ -14,7 +14,7 @@
 #' parse_hms("12:34:56")
 #' parse_hms("12:34:56.789")
 parse_hms <- function(x) {
-  as_hms(as.difftime(as.character(x), format = "%H:%M:%OS", units = "secs"))
+  parse_time(x, format = "%H:%M:%OS")
 }
 
 #' @rdname parse_hms
@@ -24,5 +24,22 @@ parse_hms <- function(x) {
 #' @examples
 #' parse_hm("12:34")
 parse_hm <- function(x) {
-  as_hms(as.difftime(as.character(x), format = "%H:%M", units = "secs"))
+  parse_time(x, format = "%H:%M")
+}
+
+parse_time <- function(x, format) {
+  if (length(x) == 0) {
+    return(hms())
+  }
+
+  parsed <- strptime(
+    paste0("1970-01-01 ", as.character(x)),
+    format = paste0("%Y-%m-%d ", format),
+    tz = "UTC"
+  )
+  hms(
+    seconds = parsed$sec,
+    minutes = parsed$min,
+    hours = parsed$hour + (parsed$mday - 1L) * 24L
+  )
 }
